@@ -158,31 +158,21 @@ class YandexParser(object):
         for block in blocks:
             block['a'] = a
 
-    def get_current_query(self):
-        import urllib
-
-        # misspell
-        match = re.search(
-            ur'<a class="[^"]+misspell__button-control[^"]*"[^>]+?href="[^"]+?text=([^&]+?)&',
-            self.content
-        )
-        if match:
-            encoded_query = match.group(1).encode('utf8')
-            query = urllib.unquote_plus(encoded_query)
-            query = query.replace('&nbsp;', ' ')
-            return query
-
-        match = re.search(
-            r'<meta property=og:title content="([^"]+?)">',
-            self.content
-        )
-        if match:
-            return match.group(1)
-
+    def get_current_search_query(self):
         match = re.search(
             r'<input class="(?:input__control mini-suggest__input|header3__input[^"]+?)"[^>]+?name="text"[^>]+?value="([^"]+?)"',
             self.content
         )
+        if match:
+            return match.group(1).replace('&nbsp;', ' ')
+
+        raise YandexParserError(u'не удалось найти текущий запрос')
+
+    def get_current_query(self):
+        match = re.search(
+            r'<meta property="?og:title"? content="?([^">]+?)"?>',
+            self.content
+        )
         if match:
             return match.group(1)
 
